==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/bedrockagentcore/CodeInterpreterCustomReference.java <==
package software.amazon.awscdk.interfaces.bedrockagentcore;

/**
 * A reference to a CodeInterpreterCustom resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.bedrockagentcore.*;
 * CodeInterpreterCustomReference codeInterpreterCustomReference = CodeInterpreterCustomReference.builder()
 *         .codeInterpreterId("codeInterpreterId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:03.004Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_bedrockagentcore.CodeInterpreterCustomReference")
@software.amazon.jsii.Jsii.Proxy(CodeInterpreterCustomReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CodeInterpreterCustomReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The CodeInterpreterId of the CodeInterpreterCustom resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getCodeInterpreterId();

    /**
     * @return a {@link Builder} of {@link CodeInterpreterCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CodeInterpreterCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CodeInterpreterCustomReference> {
        java.lang.String codeInterpreterId;

        /**
         * Sets the value of {@link CodeInterpreterCustomReference#getCodeInterpreterId}
         * @param codeInterpreterId The CodeInterpreterId of the CodeInterpreterCustom resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder codeInterpreterId(java.lang.String codeInterpreterId) {
            this.codeInterpreterId = codeInterpreterId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CodeInterpreterCustomReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CodeInterpreterCustomReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CodeInterpreterCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CodeInterpreterCustomReference {
        private final java.lang.String codeInterpreterId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.codeInterpreterId = software.amazon.jsii.Kernel.get(this, "codeInterpreterId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.codeInterpreterId = java.util.Objects.requireNonNull(builder.codeInterpreterId, "codeInterpreterId is required");
        }

        @Override
        public final java.lang.String getCodeInterpreterId() {
            return this.codeInterpreterId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("codeInterpreterId", om.valueToTree(this.getCodeInterpreterId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_bedrockagentcore.CodeInterpreterCustomReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CodeInterpreterCustomReference.Jsii$Proxy that = (CodeInterpreterCustomReference.Jsii$Proxy) o;

            return this.codeInterpreterId.equals(that.codeInterpreterId);
        }

        @Override
        public final int hashCode() {
            int result = this.codeInterpreterId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/bedrockagentcore/CodeInterpreterCustomReference.java <==
package software.amazon.awscdk.interfaces.bedrockagentcore;

/**
 * A reference to a CodeInterpreterCustom resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.bedrockagentcore.*;
 * CodeInterpreterCustomReference codeInterpreterCustomReference = CodeInterpreterCustomReference.builder()
 *         .codeInterpreterArn("codeInterpreterArn")
 *         .codeInterpreterId("codeInterpreterId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:32.156Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_bedrockagentcore.CodeInterpreterCustomReference")
@software.amazon.jsii.Jsii.Proxy(CodeInterpreterCustomReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CodeInterpreterCustomReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the CodeInterpreterCustom resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getCodeInterpreterArn();

    /**
     * The CodeInterpreterId of the CodeInterpreterCustom resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getCodeInterpreterId();

    /**
     * @return a {@link Builder} of {@link CodeInterpreterCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CodeInterpreterCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CodeInterpreterCustomReference> {
        java.lang.String codeInterpreterArn;
        java.lang.String codeInterpreterId;

        /**
         * Sets the value of {@link CodeInterpreterCustomReference#getCodeInterpreterArn}
         * @param codeInterpreterArn The ARN of the CodeInterpreterCustom resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder codeInterpreterArn(java.lang.String codeInterpreterArn) {
            this.codeInterpreterArn = codeInterpreterArn;
            return this;
        }

        /**
         * Sets the value of {@link CodeInterpreterCustomReference#getCodeInterpreterId}
         * @param codeInterpreterId The CodeInterpreterId of the CodeInterpreterCustom resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder codeInterpreterId(java.lang.String codeInterpreterId) {
            this.codeInterpreterId = codeInterpreterId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CodeInterpreterCustomReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CodeInterpreterCustomReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CodeInterpreterCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CodeInterpreterCustomReference {
        private final java.lang.String codeInterpreterArn;
        private final java.lang.String codeInterpreterId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.codeInterpreterArn = software.amazon.jsii.Kernel.get(this, "codeInterpreterArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.codeInterpreterId = software.amazon.jsii.Kernel.get(this, "codeInterpreterId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.codeInterpreterArn = java.util.Objects.requireNonNull(builder.codeInterpreterArn, "codeInterpreterArn is required");
            this.codeInterpreterId = java.util.Objects.requireNonNull(builder.codeInterpreterId, "codeInterpreterId is required");
        }

        @Override
        public final java.lang.String getCodeInterpreterArn() {
            return this.codeInterpreterArn;
        }

        @Override
        public final java.lang.String getCodeInterpreterId() {
            return this.codeInterpreterId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("codeInterpreterArn", om.valueToTree(this.getCodeInterpreterArn()));
            data.set("codeInterpreterId", om.valueToTree(this.getCodeInterpreterId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_bedrockagentcore.CodeInterpreterCustomReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CodeInterpreterCustomReference.Jsii$Proxy that = (CodeInterpreterCustomReference.Jsii$Proxy) o;

            if (!codeInterpreterArn.equals(that.codeInterpreterArn)) return false;
            return this.codeInterpreterId.equals(that.codeInterpreterId);
        }

        @Override
        public final int hashCode() {
            int result = this.codeInterpreterArn.hashCode();
            result = 31 * result + (this.codeInterpreterId.hashCode());
            return result;
        }
    }
}
